#
# spec file for package pam_mount (Version 0.18)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild
# usedforbuild    aaa_base acl attr audit-libs autoconf automake bash bind-libs bind-utils binutils bison brp-check-internal bzip2 coreutils cpio cpp cracklib cvs cyrus-sasl db diffutils e2fsprogs file filesystem fillup findutils flex gawk gcc gdbm gdbm-devel gettext gettext-devel glib2 glib2-devel glibc glibc-32bit glibc-devel glibc-locale gnome-filesystem gpm grep groff gzip info insserv klogd less libacl libattr libcom_err libgcc libgssapi libmudflap libnscd libstdc++ libtool libxcrypt libzio m4 make man mktemp module-init-tools ncurses ncurses-devel net-tools netcfg openldap2-client openssl openssl-devel pam pam-devel pam-modules patch perl permissions pkgconfig popt post-build-checks procinfo procps psmisc pwdutils rcs readline rpm sed strace sysvinit tar tcpd texinfo timezone unzip util-linux vim zlib zlib-devel


Name:           pam_mount
BuildRequires:  glib2-devel openssl-devel pam-devel
Summary:        A PAM Module that can Mount Volumes for a User Session.
Version:        0.18
Release:        29.20
License:        LGPL v2.1 or later
Prefix:         /usr
Group:          System/Libraries
Source:         %{name}-%{version}.tar.bz2
Patch0:         pam_mount-0.18-umount-home-dir.dif
Patch1:         pam_mount-chownuid-fix.diff
Patch2:         pam_mount-0.18-bump-max-par.diff
Patch3:         pam_mount-0.18-disable-debug.diff
Patch4:         pam_mount-0.18-fix-pmvarrun-ref-count.dif
Patch5:         pam_mount-0.18-sec-check-luserconf.dif
Patch6:         pam_mount-0.18-fix-symlink-attack.dif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://www.flyn.org/projects/pam_mount/

%description
This module is aimed at environments with SMB (Samba or Windows NT) or
NCP (Netware or Mars-NWE) servers that Unix users wish to access
transparently. It facilitates access to private volumes of these types.
This module also supports mounting home directories using loopback
encrypted filesystems. The module was originally written for use on the
Linux operating system but has since been modified to work on several
flavors of BSD.

o Every user can access their own volumes

o The user only needs to type the password once (at login)

o The mounting process is transparent to the user

o There is no need to keep the login passwords in any additional files

o The volumes are unmounted on logout, so it saves system resources,
avoiding the need to list every possibly useful remote volume in
/etc/fstab or in an automount/supermount config file. This is also
necessary for securing encrypted filesystems.

Pam_mount "understands" SMB, NCP, and any type of filesystem that can
be mounted using the standard mount command. If someone has a
particular need for a different filesystem, feel free to ask me to
include it and send me patches.



%debug_package
%prep
%setup -q
%patch0
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6

%build
CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" ./configure \
	--prefix=%{_prefix} --with-slibdir=/%{_lib} --mandir=%{_mandir}
make

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=${RPM_BUILD_ROOT}
# Remove static and libtool version
rm ${RPM_BUILD_ROOT}/%{_lib}/security/pam_mount.{a,la}
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/security
cp config/pam_mount.conf ${RPM_BUILD_ROOT}%{_sysconfdir}/security
# remove mount_ehd, it's only for OpenBSD
rm $RPM_BUILD_ROOT%{_prefix}/bin/mount_ehd
rm $RPM_BUILD_ROOT%{_mandir}/man8/mount_ehd.8

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc AUTHORS COPYING NEWS README FAQ
/%{_lib}/security/pam_mount*.so
%{_prefix}/bin/mkehd
%{_prefix}/bin/autoehd
%{_prefix}/bin/passwdehd
/sbin/mount.crypt
/sbin/umount.crypt
%{_sbindir}/pmvarrun
%config(noreplace) %{_sysconfdir}/security/pam_mount.conf
%doc %{_mandir}/man1/mkehd.1.gz
%doc %{_mandir}/man8/autoehd.8.gz
%doc %{_mandir}/man8/mount.crypt.8.gz
%doc %{_mandir}/man8/pam_mount.8.gz
%doc %{_mandir}/man8/passwdehd.8.gz
%doc %{_mandir}/man8/pmvarrun.8.gz
%doc %{_mandir}/man8/umount.crypt.8.gz

%changelog
* Mon Jan 12 2009 - mc@suse.de
- fix symlink attack (CVE-2008-5138) [bnc#465303]
* Fri Sep 05 2008 - mc@suse.de
- re-add security-critical checks for user-defined volumes
  (bnc#423557)
* Wed Apr 04 2007 - crivera@suse.de
- Don't package mount_ehd, it's only for
  OpenBSD. Fixes 256214
* Tue Mar 13 2007 - mc@suse.de
- fix reference counting of pmvarrun app
  [#252243]
* Tue Jan 23 2007 - mc@suse.de
- fix umount encrypted homedirectories
  [#237793]
* Thu Jan 18 2007 - mc@suse.de
- disable debug
- increase MAX_PAR to be able to read longer keys
* Fri Jan 12 2007 - mc@suse.de
- add patch to kill all remaining user processes before
  unmounting crypted partition
  pam_mount-0.18-umount-home-dir.dif [needed for Feature #253]
- use UID of specified user for owner change of mount point
  (pam_mount-chownuid-fix.diff)
* Thu Dec 21 2006 - jhargadon@suse.de
- submitting package from the 10.2 branch to sle10-sp (fate #253)
* Tue Sep 12 2006 - mc@suse.de
- Update to 0.18
  * fixes memory corruptions, zero termination, segfaults
  * A crash on x86_64 has been fixed. pam_mount now changes
  to the root directory before attempting to (un)mount
* Mon Jul 31 2006 - kukuk@suse.de
- Update to version 0.16
  bugfix release
* Wed Jan 25 2006 - mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec 22 2005 - varkoly@suse.de
- Update to version 0.10.0
* Mon Dec 19 2005 - ro@suse.de
- added symlinks to package
* Mon Jul 11 2005 - schubi@suse.de
- Update to version 0.9.25
* Mon Apr 11 2005 - kukuk@suse.de
- Update to version 0.9.22 [Bug #65110]
* Thu Jan 15 2004 - kukuk@suse.de
- Build as user
- Add pam-devel to neededforbuild
* Mon Jan 12 2004 - kukuk@suse.de
- Update to version 0.9.9
* Mon Oct 27 2003 - kukuk@suse.de
- Update to version 0.9.6 [Bug #32216]
* Wed May 28 2003 - kukuk@suse.de
- Initial package
